@@ -1,25 +1,11 @@
 /*
-    Copyright (c) 2002-2004 Marc Mutz <mutz@kde.org>
-    Copyright (c) 2007 Tom Albers <tomalbers@kde.nl>
+    SPDX-FileCopyrightText: 2002-2004 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2007 Tom Albers <tomalbers@kde.nl>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "identity.h"
-#include "signature.h"
 
 #include "kidentitymanagement_debug.h"
 #include <KConfigGroup>
@@ -37,7 +23,6 @@ static Identity *identityNull = nullptr;
 Q_DECLARE_METATYPE(KIdentityManagement::Signature)
 
 Identity::Identity(const QString &id, const QString &fullName, const QString &emailAddr, const QString &organization, const QString &replyToAddr)
-    : mIsDefault(false)
 {
     qRegisterMetaType<Signature>();
     qRegisterMetaTypeStreamOperators<Signature>();
